@@ -1,5 +1,5 @@
 package Hubot::Scripts::tweet;
-$Hubot::Scripts::tweet::VERSION = '0.2.7';
+$Hubot::Scripts::tweet::VERSION = '0.2.8';
 use strict;
 use warnings;
 use JSON::XS;
@@ -24,7 +24,8 @@ sub load {
                     my ( $body, $hdr ) = @_;
                     return if ( !$body || !$hdr->{Status} =~ /^2/ );
                     my $tweet = decode_json($body);
-                    $msg->send("$tweet->{user}{screen_name}: $tweet->{text}");
+                    my $text  = "$tweet->{user}{screen_name}: $tweet->{text}";
+                    $msg->send( split /\n/, $text );
                 }
                 );
             $msg->message->finish;
@@ -75,7 +76,7 @@ Hubot::Scripts::tweet
 
 =head1 VERSION
 
-version 0.2.7
+version 0.2.8
 
 =head1 SYNOPSIS
 
